using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;

using VirtualLab.Programming;
using VirtualLabAPI.Core.BasicFunctions;
using VirtualLabAPI.Core.Common;
using VirtualLabAPI.Core.DataVisualization;
using VirtualLabAPI.Core.FieldRepresentations;
using VirtualLabAPI.Core.Functions;
using VirtualLabAPI.Core.GeometryDescription;
using VirtualLabAPI.Core.LightPath;
using VirtualLabAPI.Core.Materials;
using VirtualLabAPI.Core.Modules;
using VirtualLabAPI.Core.Numerics;
using VirtualLabAPI.Core.Numerics.Region2D;
using VirtualLabAPI.Core.OpticalSystems;
using VirtualLabAPI.Core.Propagation;

namespace OwnCode {
    public class VLModule : IVLModule {
        public void Run() {
            
            // ask for input data array that contains the imported information
            DataArray2D inputDataArray = (DataArray2D) VL_GUI.SelectOpenDataArray2D("Select Input Data Array");
            // check the data format of the input data array
            if(inputDataArray.Data.Length != 1){
                VL_GUI.WriteLineToMessagesTab("Input data array contains more than one layer.");
            }
            else{
                // get sampling points of the data
                Vector SamplingPoints = inputDataArray.Data[0].SamplingPoints;
                if(SamplingPoints.X != 2){
                    VL_GUI.WriteLineToMessagesTab("Input data array contains more than two columns.");
                }
                else{
                    // get actual data from imported data array
                    double[,] importedData = new double[SamplingPoints.X, SamplingPoints.Y];
                    for(int iY = 0; iY < SamplingPoints.Y; iY++)
                    {
                        importedData[0, iY] = inputDataArray.Data[0][0, iY].Re * 1E-9; // conversion from [nm] to [m] for wavelength
                        importedData[1, iY] = inputDataArray.Data[0][1, iY].Re * 1E-30; // conversion from [fs^2] to [s^2] for GDD
                    }
                    // generate non-equidistance 1D numerical data array based on input
                    DataArray1D data1D = new DataArray1D(importedData,
                        PhysicalProperty.ArbitraryUnit,
                        "Imported Data",
                        PhysicalProperty.Length,
                        "Wavelength",
                        importedData[0, SamplingPoints.Y-1],
                        new ExtrapolationInfo(ExtrapolationType.BorderContinuation, 0.0), // ...
                        InterpolationMethodForNonequidistantData.LinearOnRealAndImaginaryPart);
                        
                    // display data
                    VL_GUI.ShowDocument(data1D);
                    
                }
        }
            
            
        }
    }
}